# Minecraft with Tailscale Integration

![Minecraft with Tailscale](https://www.minecraft.net/content/dam/minecraftnet/games/minecraft/logos/Global-Header_MCCB-Logo_300x51.svg "Minecraft")

This project sets up a Minecraft instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your Minecraft instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Basic understanding of Docker and networking concepts

## Project Structure
```
ts-minecraft/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/  # Persistent Tailscale state
│   └── config/         # Tailscale configuration files
└── minecraft/
    └── data/         # minecraft data
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone https://gitea.damconsulting.llc/DAM/ts-minecraft
   cd ts-minecraft
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data minecraft/data
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations
        - CAUTION: Changing `"${TS_CERT_DOMAIN}:443": false` to `true` will expose the service to the internet

4. Configure Minecraft
    - See {{service_docs}} for configuration options

5. Start the Services
    ```bash
    docker compose up -d
    ```

6. Wait for Certificate to propagate [~2m] 

7. Login

## Services

### minecraft-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: minecraft-ts
- Hostname: minecraft
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### minecraft

- Depends on minecraft-ts service

## Usage

- After starting the services your service should be available via tailnet at `https://minecraft.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://minecraft.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs minecraft-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 25565:25565
    ```
- Stopping the Services
    ```bash
    docker compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs minecraft-ts
    docker logs minecraft
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting

## Notes
- The Minecraft service uses the Tailscale service's network stack via `network_mode: service:minecraft-ts`
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For MODS there is an AWESOME tool for modifying a minecraft docker compose deployment. https://setupmc.com/java-server/
- For more information:
    - Tailscale documentation: https://tailscale.com/kb/
    - Minecraft documentation: https://docker-minecraft-server.readthedocs.io/en/latest/
    - Minecraft repository: https://github.com/itzg/docker-minecraft-server